# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Digest-SHA
Epoch:		1
Version:	6.04
Release:	1.%{__distinit}%{__distvers}
Summary:	Perl extension for SHA-1/224/256/384/512
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Digest-SHA
Source0:	https://cpan.metacpan.org/modules/by-module/Digest/Digest-SHA-%{version}.tar.gz
Patch0:		Digest-SHA-5.71-perl-path.patch
Patch1:		Digest-SHA-5.93-Reset-CFLAGS.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Getopt::Std)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Digest::base)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(integer)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Script Runtime
BuildRequires:	perl(Getopt::Long)
# Test Suite
BuildRequires:	perl(FileHandle)
# Optional Tests
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 0.08
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)
Requires:	perl(Digest::base)
Requires:	perl(XSLoader)

# Filter bogus provides of perl shared objects
%{?perl_default_filter}

%description
Digest::SHA is a complete implementation of the NIST Secure Hash Standard. It
gives Perl programmers a convenient way to calculate SHA-1, SHA-224, SHA-256,
SHA-384, SHA-512, SHA-512/224, and SHA-512/256 message digests. The module can
handle all types of input, including partial-byte data.

%prep
%setup -q -n Digest-SHA-%{version}

# Fix perl interpreter location for examples
%patch0 -p1

# Since 5.80, upstream overrides CFLAGS because they think it improves
# performance; revert it
%patch1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes examples/ README
%{_bindir}/shasum
%{_mandir}/man1/shasum.1*
%{_mandir}/man3/Digest::SHA.3*
%{perl_vendorarch}/auto/Digest/
%{perl_vendorarch}/Digest/

%changelog
* Sun Feb 26 2023 Paul Howarth <paul@city-fan.org> - 1:6.04-1
- Update to 6.04
  - Modified SHA_INIT/sharewind to silence warnings from gcc 12
    (CPAN RT#146585)
- Use SPDX-format license tag

* Tue Aug  9 2022 Paul Howarth <paul@city-fan.org> - 1:6.03-1
- Update to 6.03
  - Corrected addfile to report error when stdin is a directory
    (CPAN RT#143899)

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 1:6.02-488
- Perl 5.36 rebuild

* Sat May 22 2021 Paul Howarth <paul@city-fan.org> - 1:6.02-477
- Perl 5.34 rebuild

* Fri Jun 26 2020 Paul Howarth <paul@city-fan.org> - 1:6.02-457
- Perl 5.32 rebuild

* Sun Jun  2 2019 Paul Howarth <paul@city-fan.org> - 1:6.02-438
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1:6.02-2
- Perl 5.28 rebuild

* Mon Apr 23 2018 Paul Howarth <paul@city-fan.org> - 1:6.02-1
- Update to 6.02
  - Silenced compiler warnings from VS2017 (CPAN RT#124477)
  - Modified addfile to return error when given a directory name, which makes
    behaviour consistent with GNU coreutils shaXsum

* Tue Dec 26 2017 Paul Howarth <paul@city-fan.org> - 1:6.01-1
- Update to 6.01
  - Added "--ignore-missing" and "--strict" options to shasum
    - Consistent with GNU coreutils
    - CPAN RT#123897
  - Removed PERL_CORE preambles from test scripts
    - Preambles no longer needed for core testing
    - CPAN RT#123863

* Mon Dec 11 2017 Paul Howarth <paul@city-fan.org> - 1:6.00-1
- Update to 6.00
  - Added "tag" option (BSD-style checksums) to shasum
    - Consistent with GNU sha1sum, sha224sum, etc.
  - Modified SHA.pm to use XSLoader
    - Falls back to DynaLoader if necessary
  - Decoupled Digest::SHA and Digest::SHA::PurePerl
    - Scripts/tests in each module now fully independent
    - Digest::SHA::PurePerl to be phased out eventually
    - Past versions will remain available

* Wed Oct  4 2017 Paul Howarth <paul@city-fan.org> - 1:5.98-1
- Update to 5.98
  - Removed "portable" mode from shasum and addfile
    - Rarely used, mostly in outdated systems
    - Potentially confusing features (e.g. \r\r\n → \n)
    - Universal Newlines mode (-U) a much cleaner approach
    - Mimics Universal Newlines in Python
  - shasum now uses Digest::SHA explicitly
    - No longer loads Digest::SHA::PurePerl as an option
    - Hence no need for -R switch
    - Digest::SHA::PurePerl has its own shasum: shasumpp

* Thu Sep  7 2017 Paul Howarth <paul@city-fan.org> - 1:5.97-1
- Update to 5.97
  - Added 'quiet' option to shasum (CPAN RT#122750)
  - Expanded shasum --help message to explain use of escaped FILE names

* Mon Aug  7 2017 Paul Howarth <paul@city-fan.org> - 1:5.96-396
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 11 2017 Paul Howarth <paul@city-fan.org> - 1:5.96-394
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Thu Jul 28 2016 Paul Howarth <paul@city-fan.org> - 1:5.96-1
- Update to 5.96
  - Prevent shasum from possibly running malicious code, by removing '.' from
    @INC before module loading (CPAN RT#116513)
  - Namespace cleanup (CPAN RT#105371, CPAN RT#105372)
  - Minor code and documentation tweaks
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Sun Jan 11 2015 Paul Howarth <paul@city-fan.org> - 1:5.95-1
- Update to 5.95
  - Added support for threaded builds (CPAN RT#101260)
    - PERL_GET_NO_CONTEXT, pTHX_, aTHX_, etc.
    - Employed 'const' storage class where possible
  - Simplified shabits() routine (bitwise input buffering) (CPAN RT#101344)
    - Slightly less efficient but easier to understand
  - Minor documentation tweaks and additions
  - Modified the bit-ordering test (t/bitorder.t)
    - Supplied directory-change preamble for CORE builds

* Mon Oct 27 2014 Paul Howarth <paul@city-fan.org> - 1:5.93-1
- Update to 5.93
  - Corrected alignment problem in SHA struct (src/sha.h)
  - Provided workaround in t/methods.t for unreliable -T test (some Perl 5.8's
    mistake text for binary)
- Update patches as needed
- Classify buildreqs by usage

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 1:5.92-4
- Since 5.80, upstream overrides CFLAGS because they think it improves
  performance; revert it

* Tue Jun 10 2014 Paul Howarth <paul@city-fan.org> - 1:5.92-1
- Update to 5.92
  - Fixed reserved-word clash when compiling with C++ (CPAN RT#96090)
    - Use 'classname' instead of 'class'
  - Silenced MSC compiler warning about signed/unsigned comparison
    (CPAN RT#95830)

* Sat May 17 2014 Paul Howarth <paul@city-fan.org> - 1:5.91-1
- Update to 5.91
  - Restored original 'addfile' for use on opened file handles, which allows
    callbacks in place of actual files (e.g. with IO::Callback, CPAN RT#95643)
  - Re-established inheritance from Digest::base to pick up future Digest
    enhancements automatically
  - Cleaned up documentation

* Thu May  8 2014 Paul Howarth <paul@city-fan.org> - 1:5.90-1
- Update to 5.90
  - Consolidated all dynamic memory allocation into XSUBs
    - Streamlines referencing of SHA objects
    - Simplifies DESTROYing of objects
  - Enhanced Makefile.PL to allow 'use warnings'
    - Automatically reverts to $^W for early Perls
  - Scrubbed C and Perl code to remove all compiler warnings
- Drop %%defattr, redundant since rpm 4.4

* Sat Apr 19 2014 Paul Howarth <paul@city-fan.org> - 1:5.89-1
- Update to 5.89
  - Added universal newlines mode ("U") to addfile and shasum
    - Based on Python Universal Newlines concept
      - Newlines identical across MacOS, DOS, and UNIX
    - Will deprecate portable mode ("p") in future
      - "U" mode is cleaner and more efficient
  - Enhanced performance
    - Reduced number of dynamic memory allocations
    - Sped up addfile method with use of C code
  - Eliminated experimental -M option in favor of new -R option
    - Reverses order of digest module preference
    - Undocumented: for test and development use only
  - Sealed memory leak in SHA.xs
    - Arose only with SvPVbyte exceptions during eval
  - Patched inheritance bug (CPAN RT#94830)
    - Use sv_isobject/sv_derived_from instead of sv_isa
  - Added 'allocated' flag to SHA structure to guard against Perl double frees

* Mon Mar 17 2014 Paul Howarth <paul@city-fan.org> - 1:5.88-1
- Update to 5.88
  - Added OUTPUT clause in SHA.xs to silence compiler warning
  - Changed text file test (-T) to act on filehandles
  - Added -M and -V options to shasum, for development and testing use only

* Tue Feb 18 2014 Paul Howarth <paul@city-fan.org> - 1:5.87-1
- Update to 5.87
  - Simplified capture of intermediate SHA states:
    - Can now be done via strings (ref. getstate/putstate)
    - Substantially reduces size of src/sha.c
  - Tightened code in SHA.xs:
    - Added sv_isa checks when invoking methods
- Specify all dependencies

* Thu Jan 30 2014 Paul Howarth <paul@city-fan.org> - 1:5.86-1
- Update to 5.86
  - Improved the performance of hexadecimal output functions

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 1:5.85-3
- Perl 5.18 rebuild

* Tue Jul  9 2013 Paul Howarth <paul@city-fan.org> - 1:5.85-2
- Bump epoch as per the Fedora version

* Wed Jun 26 2013 Paul Howarth <paul@city-fan.org> - 5.85-1
- Update to 5.85
  - Workaround for repeated calls to shaclose (CPAN RT#86295)
  - Corrected typos in shasum script (CPAN RT#85430)

* Sun Mar 10 2013 Paul Howarth <paul@city-fan.org> - 5.84-1
- Update to 5.84
  - Untweaked Makefile.PL to remove dependencies of SHA.c
    - Dependencies were breaking builds on VMS
    - Retaining dependencies provides too little benefit for cost of portable
      workaround

* Mon Mar  4 2013 Paul Howarth <paul@city-fan.org> - 5.83-1
- Update to 5.83
  - Removed code for standalone C operation (no longer used)
    - Eliminates need for external symbols
    - Consolidates SHA and HMAC code
    - Reduces size of object files
  - Tweaked Makefile.PL to show dependencies of SHA.c

* Thu Jan 24 2013 Paul Howarth <paul@city-fan.org> - 5.82-1
- Update to 5.82
  - Introduced workaround for SvPVbyte bug in Perl 5.6
  - Removed "static" message schedules from C code
    - Default "auto" is now just as fast
    - Thread-safe option (-t) no longer necessary (still allowed, but ignored)
    - Simplifies source and header files (CPAN RT#82784)
  - Provided documentation to describe Unicode handling (CPAN RT#82378)
  - Updated documentation of NIST statement on SHA-1

* Mon Jan 14 2013 Paul Howarth <paul@city-fan.org> - 5.81-1
- Update to 5.81
  - Corrected load subroutine (SHA.pm) to prevent double-free (CPAN RT#82655)

* Tue Dec 11 2012 Paul Howarth <paul@city-fan.org> - 5.80-1
- Update to 5.80
  - Obtained noticeable speedup on Intel/gcc by setting -O1 and
    -fomit-frame-pointer (SHA-1 about 63% faster, SHA-2 improves 11-20%)
    (note that this package builds with distro-standard flags anyway)

* Sat Nov 24 2012 Paul Howarth <paul@city-fan.org> - 5.74-1
- Update to 5.74
  - Handle wide-string input by converting to bytes first (i.e. use SvPVbyte
    instead of SvPV in SHA.xs)

* Wed Oct 31 2012 Paul Howarth <paul@city-fan.org> - 5.73-1
- Update to 5.73
  - Provided workaround for DEC compiler bug (ref. Makefile.PL)

* Tue Sep 25 2012 Paul Howarth <paul@city-fan.org> - 5.72-1
- Update to 5.72
  - Adjusted module installation directory for later Perls: as of 5.11 Perl
    searches 'site' first, so use that as the default

* Thu Jun 28 2012 Paul Howarth <paul@city-fan.org> - 5.71-3
- BR:/R: perl(Carp) and perl(Digest::base)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than  PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Feb 29 2012 Paul Howarth <paul@city-fan.org> - 5.71-1
- Update to 5.71
  - Prevented $! from getting clobbered in _bail() routine
  - Added example of BITS mode usage to shasum documentation
- One buildreq per line for readability
- Add buildreqs for Perl core modules that might be dual-lived
- Package examples, patched for perl interpreter location

* Wed Dec 14 2011 Paul Howarth <paul@city-fan.org> - 5.70-1
- Update to 5.70
  - Added BITS mode to addfile method and shasum, which makes partial-byte
    inputs possible via files/STDIN and allows shasum to check all 8074 NIST
    Msg vectors, which previously required special programming

* Tue Nov  8 2011 Paul Howarth <paul@city-fan.org> - 5.63-1
- Update to 5.63
  - Added code to allow very large data inputs all at once (previously limited
    to several hundred MB at a time)
  - Removed outdated reference URLs from several test scripts;these URLs aren't
    essential, and often go stale (CPAN RT#68740)

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> - 5.62-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sun May 15 2011 Paul Howarth <paul@city-fan.org> - 5.62-1
- Update to 5.62
  - Removed unnecessary loading of MIME::Base64 module

* Wed Mar  9 2011 Paul Howarth <paul@city-fan.org> - 5.61-1
- Update to 5.61
  - Corrected bug in 'algorithm' method
  - Fixed -x option in Makefile.PL
  - Addressed minor documentation oversights

* Thu Mar  3 2011 Paul Howarth <paul@city-fan.org> - 5.60-1
- Update to 5.60
  - Added new SHA-512/224 and SHA-512/256 transforms
  - Simplified shasum by removing duplicative text
  - Improved efficiency of Addfile (expensive -T test now occurs only in
    portable mode)

* Wed Dec 15 2010 Paul Howarth <paul@city-fan.org> - 5.50-1
- Update to 5.50
  - Adopted convention that '-' always means STDIN; actual filename '-'
    accessed as './-' (accords with behaviour of sha1sum/md5sum)
  - Corrected undefined subroutine oversight in shasum
    (inadvertent migration of _bail() from SHA.pm)

* Sun Dec 12 2010 Paul Howarth <paul@city-fan.org> - 5.49-1
- Update to 5.49
  - Modified Addfile to accept all POSIX filenames (standard allows all
    characters except NUL and '/')
  - Updated shasum to more closely mimic sha1sum/md5sum (added "backslash
    processing" to handle newlines and backslashes in filenames)

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 5.48-3
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 5.48-2
- Fix dist tag for RHEL-6 Beta

* Tue Jan  5 2010 Paul Howarth <paul@city-fan.org> - 5.48-1
- Update to 5.48
  - Fixed "shasum -a0" option (CPAN RT#53319)
  - Updated URL for NIST test vectors (files t/nistbit.t, t/nistbyte.t)
- Dist tag for Rawhide no longer needs special-casing

* Sun Sep  6 2009 Paul Howarth <paul@city-fan.org> - 5.47-1
- Import from Fedora
- Update to 5.47 (fixes for 5.10 locations and minor bugfixes)

* Thu Apr 10 2008 Wes Hardaker <wjhns174@hardakers.net> - 5.46-1
- Update to upstream 5.46 for minor bug fixes

* Fri Nov  9 2007 Wes Hardaker <wjhns174@hardakers.net> - 5.45-1
- Update to upstream 5.45
- Change license to match new licensing tags

* Wed Aug 29 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> - 5.44-6
- Rebuild for selinux ppc32 issue.

* Fri Jun  1 2007 Wes Hardaker <wjhns174@hardakers.net> - 5.44-5
- fix changelog

* Thu May 31 2007 Wes Hardaker <wjhns174@hardakers.net> - 5.44-4
- fix description clause to remove hyphenation
- pass optimization flags to Makefile.PL
- Reverse terms in license to match perl rpm exactly

* Mon May 14 2007  Wes Hardaker <wjhns174@hardakers.net> - 5.44-3
- BuildRequire a slew of modules needed for testing/building

* Tue May  8 2007  Wes Hardaker <wjhns174@hardakers.net> - 5.44-2
- Use vendorarch instead of vendorlib

* Thu Apr 19 2007  Wes Hardaker <wjhns174@hardakers.net> - 5.44-1
- Initial version
